.. _redditbot:

Reddit Bot Example
==================

The following script is an example of how use the :attr:`.Bot.reddit_app` to obtain an
authorized ``praw.Reddit`` instance.

.. literalinclude:: ./reddit_bot.py
    :language: python
